@@ -26,8 +26,7 @@ import dask.delayed as dd
 import dask
 from dask.diagnostics import ProgressBar
 from itertools import product
-from distutils.version import LooseVersion
-
+from packaging.version import Version
 
 from hyperspy.signal import BaseSignal
 from hyperspy.defaults_parser import preferences
@@ -638,7 +637,7 @@ class LazySignal(BaseSignal):
             axes_changed = True
             if len(output_signal_size) != len(old_sig.axes_manager.signal_shape):
                 drop_axis = old_sig.axes_manager.signal_indices_in_array
-                new_axis = tuple(range(len(output_signal_size)))
+                new_axis = tuple(range(len(nav_indexes), len(nav_indexes) + len(output_signal_size)))
             else:
                 drop_axis = [it for (o, i, it) in zip(output_signal_size,
                                                       old_sig.axes_manager.signal_shape,
@@ -1175,7 +1174,7 @@ class LazySignal(BaseSignal):
             # Needs to reverse the chunks list to match dask chunking order
             signal_chunks = list(signal_chunks)[::-1]
             navigation_chunks = ['auto'] * len(self.axes_manager.navigation_shape)
-            if LooseVersion(dask.__version__) >= LooseVersion("2.30.0"):
+            if Version(dask.__version__) >= Version("2.30.0"):
                 kwargs = {'balance':True}
             else:
                 kwargs = {}
